var group__ENETPHY__DP83TG721 =
[
    [ "Dp83tg721_Cfg", "structDp83tg721__Cfg.html", [
      [ "isMDIMaster", "structDp83tg721__Cfg.html#ac0581a9903bd4c55d3b6f3d3e5605a58", null ],
      [ "enablePTPstatusFrames", "structDp83tg721__Cfg.html#a218b17c167c05ab37b743243a5d55a37", null ],
      [ "srcMacStatusFrameType", "structDp83tg721__Cfg.html#ab53191fc5d4c7216f14f573efdee485b", null ],
      [ "clockSource", "structDp83tg721__Cfg.html#a9d4ba55faf2eb4013ecd544009e5eb14", null ],
      [ "enableMediaClock", "structDp83tg721__Cfg.html#aa4db9debd32d7a3c4b5b17f5b1249c96", null ],
      [ "mediaClockMode", "structDp83tg721__Cfg.html#ab3fd43a1a509b8d4ea18d12468bf999f", null ],
      [ "enableCodecClock", "structDp83tg721__Cfg.html#a4faec932bf7c13505730ea9a90022b33", null ],
      [ "codecClkDiv", "structDp83tg721__Cfg.html#a2f950e4786d6bb20569fa49b62beccaf", null ],
      [ "mediaClkDiv", "structDp83tg721__Cfg.html#a35031498afb2864c959fcfb0091985f0", null ]
    ] ],
    [ "DP83TG721_LED_NUM", "group__ENETPHY__DP83TG721.html#ga4110adf3ba051cbd6e2ec763578eca5b", null ],
    [ "Dp83tg721_initCfg", "group__ENETPHY__DP83TG721.html#ga4dd2cdf833ebbb2f5e55985282c96e87", null ]
];